@@ -16,7 +16,7 @@ IMDB::Local - Tools to dowload and manage a local copy of the IMDB list files in
 
 =cut
 
-our $VERSION = '1.3';
+our $VERSION = '1.4';
 
 =head1 SYNOPSIS
 
@@ -214,7 +214,9 @@ sub decodeImdbKey($$$)
     $hash{parentId}=0;
     $hash{series}=0;
     $hash{episode}=0;
+    $hash{airdate}=0;
     
+
     # drop episode information - ex: "Studio One" (1948) {Twelve Angry Men (#7.1)}
     if ( $dbkey=~s/\s*\{([^\}]+)\}//o ) {
 	my $s=$1;
@@ -225,18 +227,35 @@ sub decodeImdbKey($$$)
 	    #print "title: $s\n";
 
 	    # attempt to locate parentId matching series title
-	    my $parentKey=$dbkey;
-	    $parentKey=~s/^\"//o;
-	    $parentKey=~s/\" \(/ \(/o;
+	    #my $parentKey=$dbkey;
+	    #$parentKey=~s/^\"//o;
+	    #$parentKey=~s/\" \(/ \(/o;
+
+	    #warn("checkskey $dbkey");
+	    #if ( defined($self->{seriesKeys}->{$parentKey}) ) {
+	    #$hash{parentId}=$self->{seriesKeys}->{$parentKey};
+	    #}
+	}
+ 	# "EastEnders" (1985) {(1991-10-15)}                      1991
+	elsif ( $s=~s/^\((\d\d\d\d)\-(\d\d)\-(\d\d)\)$// ) {
+	    $hash{airdate}=int("$1$2$3");
 
-	    if ( defined($self->{seriesKeys}->{$parentKey}) ) {
-		$hash{parentId}=$self->{seriesKeys}->{$parentKey};
-	    }
 	}
 	else {
 	    $hash{title}=$s;
 	}
+
+	# attempt to locate parentId matching series title
+	my $parentKey=$dbkey;
+	$parentKey=~s/^\"//o;
+	$parentKey=~s/\" \(/ \(/o;
+	
+	#warn("checkskey $dbkey");
+	if ( defined($self->{seriesKeys}->{$parentKey}) ) {
+	    $hash{parentId}=$self->{seriesKeys}->{$parentKey};
+	}
     }
+    
 		
     # change double-quotes around title to be (made-for-tv) suffix instead 
     if ( $dbkey=~s/^\"//o && $dbkey=~s/\" \(/ \(/o) {
@@ -321,7 +340,7 @@ sub decodeImdbKey($$$)
     $title=~s/(.*),\s*(The|A|Une|Las|Les|Los|L\'|Le|La|El|Das|De|Het|Een)$/$2 $1/og;
 
     # leave searchtitle empty for tv series'
-    if ( $hash{series} != 0 ) {
+    if ( $hash{series} != 0 || $hash{airdate} != 0 ) {
 	$hash{searchTitle}='';
     }
     else {
@@ -333,7 +352,8 @@ sub decodeImdbKey($$$)
 	    #$hash{searchTitleWithYear}=MakeSearchtitle($DB, $title."(".$hash{year}.")", 0);
 	}
 	else {
-	    $hash{searchTitle}=$DB->makeSearchableTitle($title."(".$hash{year}.")", 0);
+	    $hash{searchTitle}=$DB->makeSearchableTitle($title, 0);
+	    #$hash{searchTitle}=$DB->makeSearchableTitle($title."(".$hash{year}.")", 0);
 	    
 	    # todo - is this more useful ?
 	    #$hash{searchTitleWithYear}=$DB->makeSearchableTitle($title."(".$hash{year}.")", 0);
@@ -387,7 +407,7 @@ sub importMovies($$$$)
     #$DB->runSQL("BEGIN TRANSACTION");
 
     my $count=0;
-    my $tableInsert_sth=$DB->prepare('INSERT INTO Titles (TitleID, SearchTitle, Title, QualifierTypeID, Year, ParentID, Series, Episode) VALUES (?,?,?,?,?,?,?,?)');
+    my $tableInsert_sth=$DB->prepare('INSERT INTO Titles (TitleID, SearchTitle, Title, QualifierTypeID, Year, ParentID, Series, Episode, AirDate) VALUES (?,?,?,?,?,?,?,?,?)');
 
     my $potentialEntries=0;
     
@@ -401,6 +421,8 @@ sub importMovies($$$$)
 	next if ( $line=~m/\{\{SUSPENDED\}\}/o );
 	$line=~s/\n$//o;
 	
+	#next if ( !($line=~m/biography/io) );
+
 	#print "read line $lineCount:$line\n";
 	$potentialEntries++;
 
@@ -440,7 +462,8 @@ sub importMovies($$$$)
 				      $decoded->{year},
 				      $decoded->{parentId},
 				      $decoded->{series},
-				      $decoded->{episode});
+				      $decoded->{episode},
+				      $decoded->{airdate});
 	    
 	    $self->{imdbMovie2DBKey}->{$mkey}=$count;
 
@@ -1462,7 +1485,7 @@ sub _unprepStage
     $self->_redirect(undef);
 }
 
-sub importListFile($$$)
+sub _importListFile($$$)
 {
     my ($self, $DB, $type)=@_;
 
@@ -1730,6 +1753,7 @@ sub importListFile($$$)
 =head2 importList
 
 Import a list file from 'listsDir' into the IMDB::Local Database.
+Note: when 'movies' type is specified the database is reset from scratch
 
 =cut
 
@@ -1743,7 +1767,7 @@ sub importList($$)
     $self->dbinfoLoad();
 
     my $startTime=time();
-    if ( $self->importListFile($DB, $type) != 0 ) {
+    if ( $self->_importListFile($DB, $type) != 0 ) {
 	$DB->disconnect();
 	return(1);
     }
