@@ -625,7 +625,8 @@ CREATE TABLE Titles (
     Year INTEGER,
     ParentID INTEGER,			-- only set for episodes
     Series INTEGER,			-- only set for episodes (and still may be 0)
-    Episode INTEGER			-- only set for episodes (and still may be 0)
+    Episode INTEGER,			-- only set for episodes (and still may be 0)
+    AirDate INTEGER			-- some tv series have air-dates instead of series/episode information
 );
 
 -- table to give imdb list file's title string to a Title entry
